California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 037 - GENETICALLY ENGINEERED FOODS. MANDATORY LABELING. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1351240 | CALIFORNIANS FOR TRUTH IN LABELING-YES ON 37, SPONSORED BY THE CENTER FOR FOOD SAFETY ACTION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346973 | CALIFORNIA GROCERS ASSOCIATION ISSUES COMMITTEE, YES ON PROPOSITION 30, NO ON PROPOSITION 37 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1337480 | COMMITTEE FOR THE RIGHT TO KNOW: VOTE YES ON 37!!!, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1349283 | YES ON 37 LAKE COUNTY | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346175 | ORGANIC CONSUMER ORGANIZATION'S COMMITTEE FOR THE RIGHT TO KNOW ABOUT GMOS - YES ON PROP. 37 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1352976 | ENVIRONMENTAL WORKING GROUP YES ON 37 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344135 | NO ON 37: COALITION AGAINST THE DECEPTIVE FOOD LABELING SCHEME, SPONSORED BY FARMERS AND FOOD PRODUCERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1342851 | YES ON 37 FOR YOUR RIGHT TO KNOW IF YOUR FOOD HAS BEEN GENETICALLY ENGINEERED. SUPPORTED BY CONSUMER ADVOCATES, MAKERS OF ORGANIC PRODUCTS & CALIFORNIA FARMERS | SUPPORT